==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/ProgressBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ProgressBaseVariant_$type } from "./ProgressBaseVariant";
/**
 * @hidden
 */
export let ProgressBase = /*@__PURE__*/ (() => {
    class ProgressBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.b = new WCNativeHelper();
            this.i = null;
        }
        get c() {
            return this.b;
        }
        get nativeElement() {
            return this.i;
        }
        set nativeElement(a) {
            this.i = a;
            this.b.n = this.i;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get g() {
            let ret_ = this.c.m("max");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.c.u("max", value_);
        }
        get h() {
            let ret_ = this.c.m("value");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.c.u("value", value_);
        }
        get a() {
            let ret_ = this.c.m("variant");
            ret_ = enumGetBox(ProgressBaseVariant_$type, EnumUtil.getEnumValue(ProgressBaseVariant_$type, this.c.f(ProgressBaseVariant_$type, ret_)));
            return EnumUtil.getEnumValue(ProgressBaseVariant_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(ProgressBaseVariant_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.c.u("variant", value_);
        }
        get f() {
            let ret_ = this.c.m("animationDuration");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.c.u("animationDuration", value_);
        }
        get e() {
            let ret_ = this.c.m("indeterminate");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.c.u("indeterminate", value_);
        }
        get d() {
            let ret_ = this.c.m("hideLabel");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.c.u("hideLabel", value_);
        }
        get k() {
            let ret_ = this.c.m("labelFormat");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.c.u("labelFormat", value_);
        }
        l() {
            this.nativeElement.connectedCallback();
        }
    }
    ProgressBase.$t = /*@__PURE__*/ markType(ProgressBase, 'ProgressBase', BaseElement.$);
    return ProgressBase;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/ProgressBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ProgressBaseVariant_$type } from "./ProgressBaseVariant";
/**
 * @hidden
 */
export let ProgressBase = /*@__PURE__*/ (() => {
    class ProgressBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.b = new WCNativeHelper();
            this.i = null;
        }
        get c() {
            return this.b;
        }
        get nativeElement() {
            return this.i;
        }
        set nativeElement(a) {
            this.i = a;
            this.b.o = this.i;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get g() {
            let ret_ = this.c.n("max");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.c.v("max", value_);
        }
        get h() {
            let ret_ = this.c.n("value");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.c.v("value", value_);
        }
        get a() {
            let ret_ = this.c.n("variant");
            ret_ = enumGetBox(ProgressBaseVariant_$type, EnumUtil.getEnumValue(ProgressBaseVariant_$type, this.c.f(ProgressBaseVariant_$type, ret_)));
            return EnumUtil.getEnumValue(ProgressBaseVariant_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(ProgressBaseVariant_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.c.v("variant", value_);
        }
        get f() {
            let ret_ = this.c.n("animationDuration");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.c.v("animationDuration", value_);
        }
        get e() {
            let ret_ = this.c.n("indeterminate");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.c.v("indeterminate", value_);
        }
        get d() {
            let ret_ = this.c.n("hideLabel");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.c.v("hideLabel", value_);
        }
        get k() {
            let ret_ = this.c.n("labelFormat");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.c.v("labelFormat", value_);
        }
        l() {
            this.nativeElement.connectedCallback();
        }
    }
    ProgressBase.$t = /*@__PURE__*/ markType(ProgressBase, 'ProgressBase', BaseElement.$);
    return ProgressBase;
})();
